#
# spec file for package freeipmi
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2003-2008 FreeIPMI Core Team
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define srcversion %{version}
%if %{?_with_debug:1}%{!?_with_debug:0}
%define release 1.debug%{?dist}
%else
%define release 1%{?dist}
%endif

%define libipmiconsole_soname 2
%define libipmidetect_soname 0
%define libipmimonitoring_soname 6
%define libfreeipmi_soname 17

%{!?_initddir: %global _initddir %{_sysconfdir}/init.d}

Name:           freeipmi
Version:        1.6.14
Release:        2.2
URL:            http://www.gnu.org/software/freeipmi/
Source0:        http://ftp.gnu.org/gnu/freeipmi/%{name}-%{srcversion}.tar.gz
Source1:        http://ftp.gnu.org/gnu/freeipmi/%{name}-%{srcversion}.tar.gz.sig
Source2:        %{name}.keyring
Patch1:         gcc-14.patch
Summary:        IPMI Service Processor, BMC management tool
License:        GPL-3.0-or-later
Group:          System/Management
BuildRequires:  fdupes
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  texinfo
BuildRequires:  pkgconfig(systemd)
%if 0%{?fedora_version} == 20 || 0%{?rhel_version} >= 700
BuildRequires:  perl-Exporter
%endif

Obsoletes:      freeipmi-ipmimonitoring < %{version}
Provides:       freeipmi-ipmimonitoring = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): info
Requires(preun): info

%description
This project provides "Remote-Console" (out-of-band) and
"System Management Software" (in-band) based on Intelligent
Platform Management Interface specification.

%package devel
Summary:        Development package for FreeIPMI
Group:          Development/Tools/Other
Requires:       freeipmi = %{version}
Requires:       libfreeipmi%{libfreeipmi_soname} = %{version}
Requires:       libipmiconsole%{libipmiconsole_soname} = %{version}
Requires:       libipmidetect%{libipmidetect_soname} = %{version}
Requires:       libipmimonitoring%{libipmimonitoring_soname} = %{version}

%description devel
Development package for FreeIPMI.  This package includes the FreeIPMI
header files and static libraries.

%package bmc-watchdog
Summary:        FreeIPMI BMC watchdog
Group:          System/Management
%if 0%{?suse_version}
Requires(pre):  %fillup_prereq
%{?systemd_requires}
%endif
Requires:       freeipmi = %{version}
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
Requires(post): chkconfig
Requires(preun): chkconfig
%endif
Requires:       logrotate

%description bmc-watchdog
Provides a watchdog daemon for OS monitoring and recovery.

%package ipmidetectd
Summary:        IPMI node detection monitoring daemon
Group:          System/Management
Requires:       freeipmi = %{version}
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
Requires(post): chkconfig
Requires(preun): chkconfig
%endif
%{?systemd_requires}

%description ipmidetectd
This service detects and monitors IPMI nodes.

%package ipmiseld
Summary:        Polls system event logs (SEL)
Group:          System/Management
Requires:       freeipmi = %{version}
Provides:       freeipmi:/usr/sbin/ipmiseld
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
Requires(post): chkconfig
Requires(preun): chkconfig
%endif
%{?systemd_requires}

%description ipmiseld
The daemon  polls  the system event log (SEL) of specified hosts and stores the
logs into the local syslog. By default, the daemon can also make best efforts
to manage the remote SEL buffer to ensure events are never lost.
Recent logging data will be cached to disk to ensure that SEL events are
not missed in the event the client or server is rebooted.

%if %{?_with_debug:1}%{!?_with_debug:0}
  %define _enable_debug --enable-debug --enable-trace
%endif

%package -n libipmiconsole%{libipmiconsole_soname}
Summary:        FreeIPMI library
Group:          System/Libraries

%description -n libipmiconsole%{libipmiconsole_soname}
This project provides "Remote-Console" (out-of-band) and
"System Management Software" (in-band) based on Intelligent
Platform Management Interface specification.

This package contains the libipmiconsole library.

%package -n libipmidetect%{libipmidetect_soname}
Summary:        FreeIPMI library
Group:          System/Libraries

%description -n libipmidetect%{libipmidetect_soname}
This project provides "Remote-Console" (out-of-band) and
"System Management Software" (in-band) based on Intelligent
Platform Management Interface specification.

This package contains the libipmidetect library.

%package -n libipmimonitoring%{libipmimonitoring_soname}
Summary:        FreeIPMI library
Group:          System/Libraries

%description -n libipmimonitoring%{libipmimonitoring_soname}
This project provides "Remote-Console" (out-of-band) and
"System Management Software" (in-band) based on Intelligent
Platform Management Interface specification.

This package contains the libipmimonitoring library.

%package -n libfreeipmi%{libfreeipmi_soname}
Summary:        FreeIPMI library
Group:          System/Libraries

%description -n libfreeipmi%{libfreeipmi_soname}
This project provides "Remote-Console" (out-of-band) and
"System Management Software" (in-band) based on Intelligent
Platform Management Interface specification.

This package contains the libfreeipmi library.

%prep
%autosetup -p1 -n %{name}-%{srcversion}

%build
# simple .spec expressions for SLE10

%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version}
%if 0%{?fedora_version} < 21
%define docpath %{_docdir}/%{name}-%{version}
%else
%define docpath %{_docdir}/%{name}
%endif
%else
%define docpath %{_docdir}/%{name}
%endif

%define configure_systemd --with-systemdsystemunitdir=%{_unitdir}

%configure --program-prefix=%{?_program_prefix:%{_program_prefix}} \
           --docdir=%{docpath} \
           %{?configure_systemd} \
           %{?_enable_debug} --disable-static
CFLAGS="%{optflags}" make %{?_smp_mflags}

%install
mkdir -p %{buildroot}

%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
# /etc/rc.d/init.d
# 'make install' installs to /etc/init.d
# /etc/init.d -> /etc/rc.d/init.d
mkdir -p %{buildroot}/%{_sysconfdir}/rc.d/init.d
(cd %{buildroot}/%{_sysconfdir}; ln -s rc.d/init.d init.d)
%endif

%if 0%{?suse_version}
%makeinstall
%else
make install DESTDIR=%{buildroot}
%endif

mkdir -p %{buildroot}%{_datadir}/doc/packages/freeipmi-bmc-watchdog
mv %{buildroot}%{_datadir}/doc/packages/freeipmi/*bmc-watchdog* %{buildroot}%{_datadir}/doc/packages/freeipmi-bmc-watchdog
mkdir -p %{buildroot}%{_datadir}/doc/packages/freeipmi-ipmiseld
mv %{buildroot}%{_datadir}/doc/packages/freeipmi/*ipmiseld* %{buildroot}%{_datadir}/doc/packages/freeipmi-ipmiseld

ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcbmc-watchdog
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcipmidetectd
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcipmiseld

# Silent build check warning
rm -f %{buildroot}%{_datadir}/doc/packages/freeipmi/INSTALL
rm -rf %{buildroot}%{_datadir}/doc/packages/freeipmi/contrib
rm -rf %{buildroot}%{_datadir}/doc/packages/freeipmi/freeipmi-design.txt
rm -rf %{buildroot}%{_datadir}/doc/packages/freeipmi/freeipmi-testing.txt

%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
# remove /etc/init.d -> /etc/rc.d/init.d
(cd %{buildroot}/%{_sysconfdir}; rm init.d)
%endif

# fix coherance problems with associated script filenames
rm -f %{buildroot}%{_infodir}/dir
# Remove .la files
rm -rf %{buildroot}/%{_libdir}/*.la

%if 0%{?suse_version}
mkdir -p %{buildroot}%{_fillupdir}
mv %{buildroot}%{_sysconfdir}/sysconfig/bmc-watchdog %{buildroot}%{_fillupdir}/sysconfig.bmc-watchdog
%endif

%if 0%{?suse_version} > 1010
%fdupes $RPM_BUILD_ROOT
%endif

%post
if [ -x /sbin/install-info ]; then
   /sbin/install-info %{_infodir}/freeipmi-faq.info.gz %{_infodir}/dir
fi
/sbin/ldconfig

%preun
if [ $1 = 0 ]; then
   if [ -x /sbin/install-info ]; then
      /sbin/install-info --delete %{_infodir}/freeipmi-faq.info.gz %{_infodir}/dir
   fi
fi

%postun -p /sbin/ldconfig

%post   -n libipmiconsole%{libipmiconsole_soname} -p /sbin/ldconfig
%postun -n libipmiconsole%{libipmiconsole_soname} -p /sbin/ldconfig

%post   -n libipmidetect%{libipmidetect_soname} -p /sbin/ldconfig
%postun -n libipmidetect%{libipmidetect_soname} -p /sbin/ldconfig

%post   -n libipmimonitoring%{libipmimonitoring_soname} -p /sbin/ldconfig
%postun -n libipmimonitoring%{libipmimonitoring_soname} -p /sbin/ldconfig

%post   -n libfreeipmi%{libfreeipmi_soname} -p /sbin/ldconfig
%postun -n libfreeipmi%{libfreeipmi_soname} -p /sbin/ldconfig

%post bmc-watchdog
%if 0%{?suse_version}
%{fillup_only}
%endif
%service_add_post bmc-watchdog.service

%pre bmc-watchdog
%service_add_pre bmc-watchdog.service

%postun bmc-watchdog
%service_del_postun bmc-watchdog.service

%preun bmc-watchdog
%service_del_preun bmc-watchdog.service

%post ipmidetectd
%service_add_post ipmidetectd.service

%pre ipmidetectd
%service_add_pre ipmidetectd.service

%postun ipmidetectd
%service_del_postun ipmidetectd.service

%preun ipmidetectd
%service_del_preun ipmidetectd.service

%post ipmiseld
%service_add_post ipmiseld.service

%pre ipmiseld
%service_add_pre ipmiseld.service

%preun ipmiseld
%service_del_preun ipmiseld.service
# Could have several files and files with hostname ghost directive
# might not work
rm -rf %{_localstatedir}/cache/ipmiseld/*

%postun ipmiseld
%service_del_postun ipmiseld.service

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/freeipmi/freeipmi.conf
%dir %{_sysconfdir}/freeipmi
%config %{_sysconfdir}/freeipmi/freeipmi_interpret_sel.conf
%config %{_sysconfdir}/freeipmi/freeipmi_interpret_sensor.conf
%config %{_sysconfdir}/freeipmi/ipmidetect.conf
%config %{_sysconfdir}/freeipmi/libipmiconsole.conf
%doc AUTHORS
%license %docpath/COPYING
%doc ChangeLog
%doc ChangeLog.0
%doc NEWS
%doc README
%doc README.argp
%doc README.build
%doc README.openipmi
%doc TODO
%doc %{_infodir}/*
%license %docpath/COPYING.ipmiping
%license %docpath/COPYING.ipmipower
%license %docpath/COPYING.ipmiconsole
%license %docpath/COPYING.ipmimonitoring
%license %docpath/COPYING.pstdout
%license %docpath/COPYING.ipmidetect
%license %docpath/COPYING.ipmi-fru
%license %docpath/COPYING.ZRESEARCH
%license %docpath/COPYING.ipmi-dcmi
%license %docpath/COPYING.sunbmc
%license %docpath/DISCLAIMER.ipmiping
%license %docpath/DISCLAIMER.ipmipower
%license %docpath/DISCLAIMER.ipmiconsole
%license %docpath/DISCLAIMER.ipmidetect
%license %docpath/DISCLAIMER.ipmimonitoring
%license %docpath/DISCLAIMER.pstdout
%license %docpath/DISCLAIMER.ipmi-fru
%license %docpath/DISCLAIMER.ipmiping.UC
%license %docpath/DISCLAIMER.ipmipower.UC
%license %docpath/DISCLAIMER.ipmiconsole.UC
%license %docpath/DISCLAIMER.ipmimonitoring.UC
%license %docpath/DISCLAIMER.pstdout.UC
%license %docpath/DISCLAIMER.ipmidetect.UC
%license %docpath/DISCLAIMER.ipmi-fru.UC
%license %docpath/DISCLAIMER.ipmi-dcmi
%doc doc/freeipmi-coding.txt
%doc doc/freeipmi-hostrange.txt
%doc doc/freeipmi-libraries.txt
%doc doc/freeipmi-bugs-issues-and-workarounds.txt
%doc doc/freeipmi-oem-documentation-requirements.txt

%if 0%{?fedora_version} == 20
%{docpath}
%endif
%dir %{_localstatedir}/lib/freeipmi
%ghost %{_localstatedir}/lib/freeipmi/ipckey
%{_sbindir}/ipmi-config
%{_sbindir}/bmc-config
%{_sbindir}/bmc-info
%{_sbindir}/bmc-device
%{_sbindir}/ipmi-fru
%{_sbindir}/ipmi-locate
%{_sbindir}/ipmi-oem
%{_sbindir}/ipmi-pef-config
%{_sbindir}/pef-config
%{_sbindir}/ipmi-raw
%{_sbindir}/ipmi-sel
%{_sbindir}/ipmi-sensors
%{_sbindir}/ipmi-sensors-config
%{_sbindir}/ipmiping
%{_sbindir}/ipmipower
%{_sbindir}/ipmiconsole
%{_sbindir}/ipmimonitoring
%{_sbindir}/ipmi-chassis
%{_sbindir}/ipmi-chassis-config
%{_sbindir}/ipmi-dcmi
%{_sbindir}/ipmidetect
%{_sbindir}/ipmi-console
%{_sbindir}/ipmi-detect
%{_sbindir}/ipmi-ping
%{_sbindir}/ipmi-power
%{_sbindir}/rmcp-ping
%{_sbindir}/rmcpping
%{_sbindir}/ipmi-pet
%{_mandir}/man8/bmc-config.8*
%{_mandir}/man5/bmc-config.conf.5*
%{_mandir}/man8/bmc-info.8*
%{_mandir}/man8/bmc-device.8*
%{_mandir}/man8/ipmi-fru.8*
%{_mandir}/man8/ipmi-locate.8*
%{_mandir}/man8/ipmi-pef-config.8*
%{_mandir}/man8/ipmi-config.8*
%{_mandir}/man5/ipmi-config.conf.5*
%{_mandir}/man8/pef-config.8*
%{_mandir}/man8/ipmi-oem.8*
%{_mandir}/man8/ipmi-raw.8*
%{_mandir}/man8/ipmi-sel.8*
%{_mandir}/man8/ipmi-sensors.8*
%{_mandir}/man8/ipmi-sensors-config.8*
%{_mandir}/man8/ipmiping.8*
%{_mandir}/man8/ipmipower.8*
%{_mandir}/man5/ipmipower.conf.5*
%{_mandir}/man8/ipmiconsole.8*
%{_mandir}/man5/ipmiconsole.conf.5*
%{_mandir}/man8/ipmimonitoring.8*
%{_mandir}/man5/ipmi_monitoring_sensors.conf.5*
%{_mandir}/man5/ipmimonitoring_sensors.conf.5*
%{_mandir}/man5/ipmimonitoring.conf.5*
%{_mandir}/man5/libipmimonitoring.conf.5*
%{_mandir}/man8/ipmi-chassis.8*
%{_mandir}/man8/ipmi-chassis-config.8*
%{_mandir}/man8/ipmi-dcmi.8*
%{_mandir}/man8/ipmidetect.8*
%{_mandir}/man5/freeipmi.conf.5*
%{_mandir}/man5/ipmidetect.conf.5*
%{_mandir}/man7/freeipmi.7*
%{_mandir}/man8/rmcp-ping.8*
%{_mandir}/man8/rmcpping.8*
%{_mandir}/man5/freeipmi_interpret_sel.conf.5*
%{_mandir}/man5/freeipmi_interpret_sensor.conf.5*
%{_mandir}/man5/libipmiconsole.conf.5*
%{_mandir}/man8/ipmi-console.8*
%{_mandir}/man8/ipmi-detect.8*
%{_mandir}/man8/ipmi-ping.8*
%{_mandir}/man8/ipmi-power.8*
%{_mandir}/man8/ipmi-pet.8*
%dir %{_localstatedir}/cache/ipmimonitoringsdrcache

%files devel
%defattr(-,root,root)
%{_libdir}/libipmiconsole.so
%{_libdir}/libfreeipmi.so
%{_libdir}/libipmidetect.so
%{_libdir}/libipmimonitoring.so
%{_libdir}/pkgconfig/*
%dir %{_includedir}/freeipmi
%dir %{_includedir}/freeipmi/api
%dir %{_includedir}/freeipmi/cmds
%dir %{_includedir}/freeipmi/debug
%dir %{_includedir}/freeipmi/driver
%dir %{_includedir}/freeipmi/fiid
%dir %{_includedir}/freeipmi/fru
%dir %{_includedir}/freeipmi/interface
%dir %{_includedir}/freeipmi/interpret
%dir %{_includedir}/freeipmi/locate
%dir %{_includedir}/freeipmi/payload
%dir %{_includedir}/freeipmi/record-format
%dir %{_includedir}/freeipmi/record-format/oem
%dir %{_includedir}/freeipmi/sdr
%dir %{_includedir}/freeipmi/sdr/oem
%dir %{_includedir}/freeipmi/sel
%dir %{_includedir}/freeipmi/sensor-read
%dir %{_includedir}/freeipmi/spec
%dir %{_includedir}/freeipmi/spec/oem
%dir %{_includedir}/freeipmi/templates
%dir %{_includedir}/freeipmi/templates/oem
%dir %{_includedir}/freeipmi/util

%{_includedir}/ipmiconsole.h
%{_includedir}/ipmidetect.h
%{_includedir}/ipmi_monitoring.h
%{_includedir}/ipmi_monitoring_bitmasks.h
%{_includedir}/ipmi_monitoring_offsets.h
%{_includedir}/freeipmi/*.h
%{_includedir}/freeipmi/api/*.h
%{_includedir}/freeipmi/cmds/*.h
%{_includedir}/freeipmi/debug/*.h
%{_includedir}/freeipmi/driver/*.h
%{_includedir}/freeipmi/fiid/*.h
%{_includedir}/freeipmi/fru/*.h
%{_includedir}/freeipmi/interface/*.h
%{_includedir}/freeipmi/interpret/ipmi-interpret.h
%{_includedir}/freeipmi/locate/*.h
%{_includedir}/freeipmi/payload/ipmi-sol-payload.h
%{_includedir}/freeipmi/record-format/*.h
%{_includedir}/freeipmi/record-format/oem/*.h
%{_includedir}/freeipmi/sdr/*.h
%{_includedir}/freeipmi/sdr/oem/*.h
%{_includedir}/freeipmi/sel/*.h
%{_includedir}/freeipmi/sensor-read/*.h
%{_includedir}/freeipmi/spec/*.h
%{_includedir}/freeipmi/spec/oem/*.h
%{_includedir}/freeipmi/templates/*.h
%{_includedir}/freeipmi/templates/oem/*.h
%{_includedir}/freeipmi/util/*.h
%{_mandir}/man3/*

%files bmc-watchdog
%defattr(-,root,root)
%dir %{_docdir}/freeipmi-bmc-watchdog
%license %{_docdir}/freeipmi-bmc-watchdog/COPYING.bmc-watchdog
%license %{_docdir}/freeipmi-bmc-watchdog/DISCLAIMER.bmc-watchdog
%license %{_docdir}/freeipmi-bmc-watchdog/DISCLAIMER.bmc-watchdog.UC
%{_unitdir}/bmc-watchdog.service
%if 0%{?suse_version}
%attr(0444,root,root) %{_fillupdir}/sysconfig.bmc-watchdog
%else
%attr(0444,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/bmc-watchdog
%endif
%{_sbindir}/bmc-watchdog
%{_sbindir}/rcbmc-watchdog
%{_mandir}/man8/bmc-watchdog.8*

%files ipmidetectd
%defattr(-,root,root)
%{_unitdir}/ipmidetectd.service
%attr(0444,root,root) %config(noreplace) %{_sysconfdir}/freeipmi/ipmidetectd.conf
%{_sbindir}/ipmidetectd
%{_sbindir}/rcipmidetectd
%{_mandir}/man5/ipmidetectd.conf.5*
%{_mandir}/man8/ipmidetectd.8*

%files ipmiseld
%defattr(-,root,root)
%config %{_sysconfdir}/freeipmi/ipmiseld.conf
%dir %{_localstatedir}/cache/ipmiseld
%{_unitdir}/ipmiseld.service
%{_sbindir}/ipmiseld
%{_sbindir}/rcipmiseld
%{_mandir}/man5/ipmiseld.conf.5*
%{_mandir}/man8/ipmiseld.8*
%dir %{_docdir}/freeipmi-ipmiseld
%license %{_docdir}/freeipmi-ipmiseld/COPYING.ipmiseld
%license %{_docdir}/freeipmi-ipmiseld/DISCLAIMER.ipmiseld

%files -n libipmiconsole%{libipmiconsole_soname}
%defattr(-,root,root)
%{_libdir}/libipmiconsole*so.%{libipmiconsole_soname}*

%files -n libipmidetect%{libipmidetect_soname}
%defattr(-,root,root)
%{_libdir}/libipmidetect*so.%{libipmidetect_soname}*

%files -n libipmimonitoring%{libipmimonitoring_soname}
%defattr(-,root,root)
%{_libdir}/libipmimonitoring.so.%{libipmimonitoring_soname}*

%files -n libfreeipmi%{libfreeipmi_soname}
%defattr(-,root,root)
%{_libdir}/libfreeipmi*so.%{libfreeipmi_soname}*

%changelog
* Mon Jun  3 2024 Klaus Kämpf <kkaempf@suse.com>
- use %%autosetup
- apply patches with -p1
* Thu Mar  7 2024 Klaus Kämpf <kkaempf@suse.com>
- fix gcc-14 build: gcc-14.patch (bsc#1220476)
* Mon Jan 29 2024 Klaus Kämpf <kkaempf@suse.com>
- freeipmi 1.6.14
  * Fix build issue common to non-x86 systems.
- freeipmi 1.6.13
  * Fix build issues on systems where inb/outb are declared with inline
    assembly.
  * Add additional sensor/event interpretations.
- freeipmi 1.6.12
  * Use poll() over select() to avoid fd limit in openipmi driver.
  * Fix potential portability problems on systems without cbrt().
  * Minor documentation updates.
* Mon Jun 12 2023 Klaus Kämpf <kkaempf@suse.com>
- freeipmi 1.6.11
  * Fix double free corner case in ipmiseld.
  * Support ISO 8601 date inputs to date range options in ipmi-sel.
  * Support Xilinx OEM FRU records.
  * Fix corner case in libipmimonitoring, support sensor if units
    is "RPM per minute", but just return "RPM" as the units.
  * Fix portability compilation on cygwin.
  * Fix typo in fiid template field that could lead to packet
    interpretation errors.
* Fri Feb 17 2023 Andreas Stieger <andreas.stieger@gmx.de>
- freeipmi 1.6.10
  * Support IPv6 Lan configuration in ipmi-config
    IPv6 configuration is supported in the new Lan6_Conf section
- add upstream signing key and source signature
* Mon Jan 16 2023 Andreas Schwab <schwab@suse.de>
- Remove obsolete ExclusiveArch
* Thu Jan 20 2022 Klaus Kämpf <kkaempf@suse.com>
- freeipmi 1.6.9
  * Support --with-systemconfigdir build option.
  * Fix build issue on musl where putmsg/getmsg are not available.
  * Fix build issue when inb/outb are not available on some systems.
  * Fix static build issues with gcrypt.
  * Add conserver documentation in faq.
  * Minor documentation updates.
* Thu Jul  8 2021 Thomas Renninger <trenn@suse.de>
- Fix: W: name-repeated-in-summary C FreeIPMI
- Fix: freeipmi-bmc-watchdog.x86_64:
  W: non-etc-or-var-file-marked-as-conffile /usr/share/fillup-templates/sysconfig.bmc-watchdog
  Declaring fillup files as conffile is not needed
- freeipmi 1.6.8
  * Fix incorrect sensor read corner case on BMCs that use non-default LUNs (LP#1926299).
  * Remove hard coded paths from system config files (i.e. mostly files
    in /etc).  Have paths updated based on options to configure.
* Sun Feb 14 2021 Andreas Stieger <andreas.stieger@gmx.de>
- freeipmi 1.6.7:
  * Do not require IPMI access when running ipmi-fru with the
  - -fru-file option
  * Minor documentation updates
- the following fixes were upstreamed:
  * Fix default permissions of various config and system files,
    drop 1103311-service-files-mode.patch
* Sun Sep  6 2020 Klaus Kämpf <kkaempf@suse.com>
- Update to 1.6.6
  o In libfreeipmi, fix segfault in SPMI parsing leading to immediate
    failures on some hardware across all tools.
* Fri May 22 2020 Klaus Kämpf <kkaempf@suse.com>
- Update to 1.6.5
  o Add FRU parsing workaround for Fujitsu Primergy RX1330, in which a
    CEh is used to indicate that no FRU data is available.
  o Misc minor fixes.
* Thu Aug 22 2019 Klaus Kämpf <kkaempf@suse.com>
- Update to 1.6.4
  o In libfreeipmi, add additional workarounds for packets that are
    re-ordered during sensor bridging.
  o In libfreeipmi, add additional sensor / event interpretations.
  o In libfreeipmi, fix error return value on bridging requests.
  o Add workaround in ipmi-sel for QuantaPlex T42D-2U motherboard,
    whichlists a SDR record that makes no sense.
  o Add workaround for Dell Poweredge FC830, which have an error
    when reading the last SDR record on a motherboard.
  o Support Supermicro X10 OEM dimm events.
* Fri Jan 25 2019 Klaus Kämpf <kkaempf@suse.com>
- Update to 1.6.3
  o In ipmi-locate, support parsing SPMI tables exported via sysfs.
  o Support Intel S2600GZ OEM sensor and SEL events.
  o Support Intel S2600WP OEM sensor and SEL events.
  o Support Gigabyte MG20-OP0-ZB OEM SEL events.
  o Fix DISCRETE_READING workaround in libipmimonitoring.
  o In libfreeipmi, add workaround for packets that are re-ordered
    during sensor bridging.
  o Minor bug fixes.
  o Various documentation updates/fixes.
* Fri Jan 11 2019 trenn@suse.de
- Add provides:freeipmi:/usr/sbin/ipmiseld to the
  freeipmi-ipmiseld split package for backward compatibility
  for now
* Fri Nov  9 2018 trenn@suse.de
- Remove has_systemd conditions
- Add rcservice shortcut links to control services
- Fix some more build warnings
- Use %%license instead of %%doc where appropriate
- Extract ipmiseld service as a separate package as done with other
  services
- Declare /var/lib/freeipmi/ipckey as %%ghost and do not create it
  explicitly in .spec file (bsc#1100124)
* Tue Aug 28 2018 trenn@suse.de
- Enable build for aarch64 (fate#326605)
* Wed Aug  1 2018 josef.moellers@suse.com
- Changed mode of .service files from 755 to 644.
  [bsc#1103311, 1103311-service-files-mode.patch]
* Fri May  4 2018 kkaempf@suse.com
- Update to 1.6.2
  o Fix error in bridging where bridged requests were sent to the
    wrong LUN.
  o Fix command parsing bugs in legacy ipmi-config scripts
    (i.e. bmc-config, ipmi-pef-config, etc.)
  o Do not output full path of daemons in syslog, output only the
    daemon name (i.e. output "ipmidetected" instead of
    "/usr/sbin/ipmidetectd").
  o Update channel range from 0-7 to 0-11, per errata IPMI update.
* Sat Feb  3 2018 kkaempf@suse.com
- Update to 1.6.1
  o Add IPv6 hostname support to FreeIPMI, all of FreeIPMI can now take
    IPv6 addresses as inputs to "host" parameters, options, or inputs.
  o Support significant portions of IPMI IPv6 configuration in
    libfreeipmi.
  o Add --no-session option in ipmi-raw.
  o Add SDR cache options to ipmi-config.
  o Legacy -f short option for --flush-cache and -Q short option for
    quiet-cache.  Backwards compatible for tools that supported it
    before.
  o In ipmi-oem, support Gigabyte get-bmc-services and
    set-bmc-services.
  o Various performance improvements:
  - Remove excessive calls to secure_memset to clear memory.
  - Remove excessive memsets and clears of data.
  - Remove unnecessary "double input checks".
  - Remove expensive input checks in libfreeipmi fiid library.
    Fallout from this may include FIID_ERR_FIELD_NOT_FOUND
    errors in different fiid functions.
  - Remove unnecessary input checks in libfreeipmi fiid library.
  - Add recent 'lookups' of fields in fiid library to internal
    cache.
  o Various minor fixes/improvements
  - Update libfreeipmi core API to use poll() instead of select(), to
    avoid issues with applications with a high number of threads.
  - As a side point, while IPv6 networking support has been added, IPv6
    configuration in ipmi-config & bmc-config is not supported in this
    release.
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Oct 18 2017 alarrosa@suse.com
- Follow the shared library packaging policy. Created new packages
  libipmiconsole2, libipmidetect0, libipmimonitoring6, libfreeipmi17
* Wed Aug 30 2017 kkaempf@suse.com
- Update to 1.5.7
  o In libipmimonitoring, fix several mem-leak corner cases.
* Thu Jul  6 2017 kkaempf@suse.com
- Update to 1.5.6
  o In libfreeipmi locate (used by ipmi-locate), use DMI firmware in
    sysfs if it exists.
  o Minor mem-leak corner case fix in libfreeipmi.
  o Minor documentation fixes.
  o Minor error message clarifications.
* Thu Mar  9 2017 sfalken@opensuse.org
- Edited %%files to clear unpackaged files builderror in
  openSUSE:Factory
* Thu Nov  3 2016 kkaempf@suse.com
- Update to 1.5.5
  o Fix invalid flag clear in libipmiconsole that can lead to a potential
    double close on a file descriptor.
  o Support Supermicro H8SGL-F OEM sensors and events.
* Tue Oct  4 2016 kkaempf@suse.com
- Update to 1.5.4
  o Various changes/fixes in libipmiconsole
  - If user retrieves file descriptor from ipmiconsole_ctx_fd,
    user is required to close it.  ipmiconsole_ctx_destroy no
    longer closes it.  This is to avoid a potential double close
    which can be a problem for multithreaded applications. This
    is a change in behavior, but we do not believe this will
    affect most applications since most users close the file
    descriptor under most scenarios anyways.
  - ipmiconsole_ctx_destroy() should now be called to free
    resources even if ipmiconsole_engine_teardown() has been
    called.  This has been done to create consistent behavior in
    the API and avoid a former segfault possibility.  This is a
    change in behavior, but we do not believe this will affect
    most applications since ipmiconsole_engine_teardown() is
    only called when an application is being shutdown.
  - The use of IPMICONSOLE_ENGINE_CLOSE_FD has been clarified in
    the header file.  Some of the prior text was unclear.
    Behavior has not been changed.
  o In ipmi-oem, support Intel get-bmc-services and set-bmc-
    services commands.
  o In ipmi-oem, support Gigabyte get-nic-mode and set-nic-mode
    commands.
  o Support Gigabyte MD90-FS0-ZB OEM SEL events.
* Tue Aug  2 2016 kkaempf@suse.com
- Update to 1.5.3
  o Update Fujitsu OEM extension product id support range.
  o In ipmiconsole, support --debugfile option for more difficult
    debugging scenarios.
  o In all sensor related tools, increase max number of record ids and
    sensor types that can be handled.
  o Fix several invalid completion code errors/values.
* Mon May 30 2016 kkaempf@suse.com
- Update to 1.5.2
  o Update configuration file parsing code to handle values up to
    1024 characters in length.
  o Set FD_CLOEXEC for ipmi driver device files opened within
    libfreeipmi.
  o Support --read-fru, --write-fru, and --device-id option in
    bmc-device.
  o Support --fru-file option in ipmi-fru.
  o Various library updates in libfreeipmi to handle new features.
* Wed Dec  2 2015 kkaempf@suse.com
- Update to 1.5.1
  o Update Intel Node Manager support for 3.0 specification.
  - Update API and fiid templates in libfreeipmi.
  - Support new OEM SEL events
  - Update ipmi-oem commands.
  - Support new get/set-turbo-synchronization-ratio
  - Support new 'policypowerdomain' option in
    get-node-manager-capabilities and set-node-manager-policy.
  - Update output of get-node-manager-policy and
    get-node-manager-capabilities for changes.
  - get/set-node-manager-alert-thresholds converted to
    get/set-node-manager-policy-alert-thresholds. Legacy
    commands still supported.
  o Update libfreeipmi for IPMI 2.0 Errata 7.
  - Support/handle FRU Multirecord NVM Express type.
  o Support Get Device SDR Info, Get Device SDR, and Reserve
    Device SDR Repository commands in libfreeipmi.
  o Support ipmi-sel OEM interpretation of Linux kernel panics.
  o Re-organize OEM header files into per-vendor files.
  o In ipmi-oem, fix error in "DNS Register BMC" output in
    "get-dns-config" output in Inventec, Quanta, and Wistron vendor
    sections.
  o Support systemd through --with-systemdsystemunitdir configure
    option.
  o Minor corner case bug fixes.
* Fri Oct 30 2015 kkaempf@suse.com
- Update to 1.4.11
  o Fix logic error with a few OEM SEL events for Intel E5 2600 V3
    motherboard.
  o Fix various logic errors in ipmi-oem Intel Node Manager extensions.
  o Documentation updates.
* Wed Oct 21 2015 kkaempf@suse.com
- Fix SLE10 and RHEL5 builds
* Wed Oct 21 2015 kkaempf@suse.com
- Update to 1.4.10
  o In ipmi-oem, support Supermicro get-power-supply-status2.
  o In ipmi-locate, fix probing issue on arm32 & 64.
  o Handle several additional completion code error message in
    libfreeipmi.
  o Handle several error handling corner cases in ipmi-sensors.
  o Support Intel E5 2600 V3 motherboard OEM SEL events.
  o Fix several errors in ipmi-oem intelnm get-node-manager-statistics
    output.
  o Fix logic errors in ipmi-oem intelnm set-node-manager-policy.
* Thu Jun 18 2015 kkaempf@suse.com
- fix Fedora/RHEL builds
* Tue Jun  2 2015 kkaempf@suse.com
- Update to 1.4.9
  o Fix strtol parse corner cases in several commands.
  o Minor documentation fixes.
* Thu Apr  2 2015 mpluskal@suse.com
- Add gpg signature
* Thu Jan  8 2015 kkaempf@suse.com
- Update to 1.4.8
  o Fix segfault in crypt code with libgcrypt versions >= 1.6.0.
  o Fix --fanout command line parse bug.
* Thu Dec 11 2014 kkaempf@suse.com
- Update to 1.4.7
  o Fix typo from FRU spec, language "Tegulu" is actually "Telugu".
  o Fix typo in SEL session output, "Invalid Username of Password" to
    "Invalid Username or Password".
  o Loop on select() call if interrupted by EINTR in openipmi, ssif,
    and sunbmc inband drivers.
  o Fix integer overflow bug in ipmi-config when configure
    vlan ID > 255.
  o Add workaround for ipmi-config issue on Supermicro X10DDW-i.
  o Fix error handling bug in bmc-info.
* Wed Oct 29 2014 kkaempf@suse.com
- Update to 1.4.6
  o In ipmi-fru, support output of DDR4 SDRAM modules.
  o Fix EFI probing on non IA64 systems.
  o Fix corner case in ipmi-raw w/ standard input or --file and
    empty lines.
  o Fix parsing corner case in ipmi-chassis.
  o Support SSIF bridging.
* Fri Aug 29 2014 juwolf@suse.com
- Remove executable flags from systemd service files to prevent
  systemd warning (bnc#893142)
* Tue Jul 29 2014 kkaempf@suse.com
- Update to 1.4.5
  o Fix libipmiconsole calculation bug w/ SOL character send size.
  o Support Supermicro H8DGU and H8DG6 OEM sensors and events.
  o Minor documentation updates.
* Mon Jun 30 2014 kkaempf@localhost
- Update to 1.4.4
  o Support retrys of SSIF reads to handle SSIF NACKs.
* Thu May  8 2014 kkaempf@suse.com
- Update to 1.4.3
  has freeipmi-1.4.2.patch included, drop local patch
* Wed May  7 2014 kkaempf@suse.com
- Update to 1.4.2
  o In ipmi-oem, support Supermicro get-power-supply-status and
    get-pmbus-power-supply-status commands.
  o Support 'ipmiping' workaround in ipmipower.
  o Minor documentation updates.
- Fix compile bug, add freeipmi-1.4.2.patch
* Tue Mar  4 2014 kkaempf@suse.com
- Update to 1.4.1
  Tools - New Features
  - -------------------
  o Support 'serialalertsdeferred' workaround in ipmiconsole.
  o Support 'solpacketseq' workaround in ipmiconsole.
  o Fix portability issues for Apple / OS X.
* Thu Feb  6 2014 kkaempf@suse.com
- Drop freeipmi-max-sensor.patch, included upstream
- Update to 1.4.0 beta0
  Tools - New Features
  - -------------------
  o Support new tool ipmi-config.  Ipmi-config is a consolidated
    configuration tool implementing everything that was previously in
    bmc-config, ipmi-pef-config, ipmi-sensors-config, and
    ipmi-chassis-config.
  - The consolidated tool will allow users to checkout, commit, and
    diff sections/fields across the four former tools using only one
    tool.
  - The consolidated tool will also allow users to checkout, commit,
    and diff new sections/fields not yet covered in the four former
    tools.
  - Legacy scripts for bmc-config, ipmi-pef-config,
    ipmi-sensors-config, and ipmi-chassis-config will point to the new
    tool with all appropriate options to ensure full backwards
    compatability.
  - The ipmi-pef-config --info option has been made legacy.  It is
    still supported but no longer advertised.
  o Support Intel Data Center Host Interface / Management Engine as
    optional driver type for in-band communication.
  - Typically these are loaded as /dev/dcmi and /dev/mei drivers.
  - This driver is identified as the "inteldcmi" type, as it is
    specific to Intel systems.
  o Support OEM extensions for Intel Windmill, Wiwynn Windmill, and
    Quanta Winterfell motherboards in ipmi-sel and ipmi-sensors.  These
    motherboards are also know as motherboards for the Open Compute
    Project (OCP).
  o Support DCMI configuration in ipmi-config.
  o Update FreeIPMI for changes in IPMI 2.0 Errata 5.  Include are:
  - New sensor events for Power Supply and OS Boot sensors.  New
    events are supported in all areas, ipmi-sensors, ipmi-sel,
    libipmimonitoring, etc.
  - PEF now supports 255 filter numbers, not 127.  This is supported
    in ipmi-config (formerly ipmi-pef-config).
  - Support get/set of new System Info Parameters Present OS Version,
    BMC URL, and Base OS/Hypervisor URL.  This is supported in
    bmc-info and bmc-device.
  o Update ipmi-oem Intel Node Manager OEM commands for changes listed
    in Intelligent Power Node Manager 2.0 specification.
  - Due to changes in the specification, minor text changes may exist
    in some output from intelnm OEM commands.
  o Update ipmi-sel to support new SEL events in Intelligent Power Node
    Manager 2.0 specification.
  Tools - Bug Fixes/Minor Changes
  - ------------------------------
  o Fix bmc-info output of GUID, format was output with two bytes out of
    order.
  - May affect scripts parsing and using the GUID.
  o Bmc-info now supports --get-system-guid and outputs the System GUID
    as well as the Device GUID by default.
  - The Device GUID is not prefixed with the text "Device GUID"
    instead of just "GUID".  Any scripts scripting against this will
    need to be adjusted.
  o Bmc-info now supports a workaround of 'guidformat' to read the GUID
    with a format a number of vendors have incorrectly used.
  o In ipmi-config's sensor configuration, decimal values that cannot be
    encoded accurately now report a clearer error message.
  Libraries
  - --------
  o Update libfreeipmi and libipmimonitoring to support IPMI 2.0 Errata 5.
    Included are:
  - Support new sensor events for Power Supply and OS Boot sensors.
  - Support PEF filter numbers up to 255.
  - Support new System Info Parameters for Present OS Version, BMC
    URL, and Base OS/Hypervisor URL.
  o Update libfreeipmi to support Intel Node Manager payloads per Intel
    Intelligent Power Node Manager 2.0 specification.
  - Due to changes in the specification, some payload fields have been
    changed.
  o Update libfreeipmi SEL sub-library to handle new event messages in
    Intelligent Power Node Manager 2.0 specification.
* Wed Jan 15 2014 kkaempf@suse.com
- Updated 1.3.4 release from upstream to support ppc64le.
* Thu Dec 19 2013 kkaempf@suse.com
- Prevent crash on systems with more than 601 sensors.
  Add freeipmi-max-sensor.patch
* Fri Dec 13 2013 kkaempf@suse.com
- FreeIPMI 1.3.4 - 12/12/13
  - ------------------------
  o Support 'solchannelsupport' workraound in ipmiconsole /
    IPMICONSOLE_WORKAROUND_SKIP_CHANNEL_PAYLOAD_SUPPORT workaround
    flag in libipmiconsole.
  o Fix SDR cache workaround for motherboards with invalid SDR record
    counts listed.
  o Workaround Supermicro bug in bmc-watchdog.
  o Fix error checks in sensor decoding functions, leading to
    possible problems in ipmi-sensors-config.
  o Update documentation with additional workarounds for motherboards.
  o Fix various minor bugs.
* Wed Oct 30 2013 kkaempf@suse.com
- FreeIPMI 1.3.3
  - ------------------------
  o Add support for intelnm get-node-manager-alert-destination and
    set-node-manager-alert-destination in ipmi-oem.
  o Under very verbose mode, ipmi-sel will now record types for OEM
    records.  This should allow OEM parses outside of FreeIPMI to more
    effectively parse OEM specific SEL records.
  o Fix big endian portability bugs.
* Sun Oct 27 2013 p.drouand@gmail.com
- Add systemd support for openSUSE >= 12.3
* Fri Oct  4 2013 kkaempf@suse.com
- FreeIPMI 1.3.2 - 09/10/13
  - ------------------------
  o Update FreeIPMI tools to check libfreeipmi API error codes
    correctly.
  o Update ipmi-api.h to list mappings of IPMI completion codes and
    RMCPPlus codes to API Error codes.
* Mon Aug 26 2013 kkaempf@suse.com
- FreeIPMI 1.3.1 - 08/22/13
  Tools - New Features
  - -------------------
  o In all tools reporting time (ipmi-sel, ipmi-fru, ipmi-oem,
    bmc-device, ipmi-sensors, ipmi-dcmi), timestamps are now reporting
    under the assumption the timestamp is already in localtime (compared
    to being in UTC time and converted to localtime).  This is by
    definition in the IPMI specification.
  o In all tools reporting time (ipmi-sel, ipmi-fru, ipmi-oem,
    bmc-device, ipmi-sensors, ipmi-dcmi), support --utc-to-localtime,
  - -localtime-to-utc, and --utc-offset options to allow users to
    adjust timestamps as needed for certain environments.
  o In ipmi-fru, support output of DDR3 SDRAM modules.
  o In ipmi-fru, support output of new FRU multirecords, most notably
    extended DC output and extended DC load (per FRU Revision 1.2
    update).
  o In bmc-device, support --get-sel-time-utc-offset and
  - -set-sel-time-utc-offset.
  Tools - Bug Fixes/Minor Changes
  - ------------------------------
  o In ipmi-fru, report power supply low/high end voltage ranges as
    signed numbers (per FRU Revision 1.2 update).
  o In ipmi-fru, output "unspecified" for manufacturing date/time or
    peak capacity as appropriate (per FRU Revision 1.2 update).
  o In ipmi-fru, bridge additional FRU entries as appropriate.
  o In all tools reporting time (ipmi-sel, ipmi-fru, ipmi-oem,
    bmc-device, ipmi-sensors, ipmi-dcmi), special timestamps such as
    Post-Init and Unspecified will now be output.
  o Fix output corner case with entity sensor names in various tools.
  Libraries
  - --------
  o In libfreeipmi, support additional chassis types (per FRU Revision
    1.2 update).
  o In libfreeipmi, support new FRU multirecord types (per FRU Revision
    1.2 update).
  o In libfreeipmi, support new IPMI_FRU_FLAGS_READ_RAW 'fru'
    sub-library flag to read data from the FRU raw without parsing
    headers/records.
  o In libfreeipmi, add support for DDR3 SDRAM FRU entries and JEDEC
    manufacturer IDs.
  o In libfreeipmi, add support for Get SEL Time UTC Offset and Set SEL
    Time UTC Offset payloads.
  o In libfreeipmi 'sel' sub-library, support
    IPMI_SEL_PARAMETER_UTC_OFFSET,
    IPMI_SEL_STRING_FLAGS_UTC_TO_LOCALTIME, and
    IPMI_SEL_STRING_FLAGS_LOCALTIME_TO_UTC options/flags.
  o In libfreeipmi, do not pad legacy byte on IPMI 1.5 packets.  Legacy
    byte should be padded on ethernet frame, not IP packet.
  o In libfreeipmi, 'sdr' sub-library, when creating SDR cache, add
    checksums to cache to ensure data in cache is not corrupted.  Older
    caches without checksums still backwards compatible supported.
  o In libfreeipmi, support new IPMI_ERR_COMMAND_INVALID_OR_UNSUPPORTED
    error code for IPMI commands that are invalid or unsupported.
* Tue Jul 23 2013 kkaempf@suse.com
- FreeIPMI 1.2.9 - 07/17/13
  - ------------------------
  o Fix threshold output corner case in ipmi-sensors.
  o Fix invalid declaration in libipmimonitoring header.
  o Fix older compiler build problems.
* Mon Jun 24 2013 kkaempf@suse.com
- FreeIPMI 1.2.8 - 06/21/13
  - ------------------------
  o Fix portability build bug on ARM systems.
  o Add 'internal IPMI error' troubleshooting to manpages.
  o Fix bmc-info corner case on Bull 510 systems.
- drop automake-1_13.patch patch, included upstream
* Tue Apr 30 2013 kkaempf@suse.com
- FreeIPMI 1.2.6 - 04/29/13
  - ------------------------
  o Support HP Proliant DL160 G8 OEM sensors.
  o Support Supermicro X9SCM-iiF OEM sensors and events.
  o Support output of temperature sampling period to ipmi-dcmi.
  o Clarify error message when SOL session cannot be stolen in
    ipmiconsole/libipmiconsole.
  o Fix dcmi rolling average time period output error
  o Fix ipmi-dcmi output errors with --get-dcmi-sensor-info.
  o Fix corner case in calculation of confidentiality pad length with
    AES-CBC-128 encryption.  Incorrect pad effects some vendor firmware
    implementations.
  o Send IPMI 2.0 packets differently than IPMI 1.5 packets, as the
    former does not require legacy pad data to be appended to
    payloads.
  o Fix Intel OEM SEL buffer overflow.
  o Fix out of trunk source build.
  Libraries
  - --------
  o Support new ipmi_rmcpplus_sendto() and ipmi_rmcpplus_recvfrom()
    functions.
  o Support new HP Proliant DL160 G8 OEM sensor events.
* Thu Feb 28 2013 kkaempf@suse.com
- fix for automake 1.13
* Thu Feb 28 2013 kkaempf@suse.com
- FreeIPMI 1.2.5 - 02/26/13
  - ------------------------
  o In all config tools (bmc-config, ipmi-pef-config,
    ipmi-chassis-config, ipmi-sensors-config), fix bug when user
    specifies --checkout and --filename option and no data outputs to
    file.
  o In all config tools, exit with value 1 when non-fatal errors
    occur.
    Exit with value 2 when fatal errors occur.
  o Support Supermicro X9SPU-F-O OEM sensors and events.
  o Support Supermicro X9DRI-LN4F+ OEM intepretations (previously
    forgotten).
  o Clarify use of --filename in config tool manpages.
- FreeIPMI 1.2.4 - 01/10/12
  - ------------------------
  o Support Supermicro X9DRI-LN4F+ OEM sensors and events.
  o Fix output corner case for "session-based" channels.
  o Fix ipmi-oem set-power-restore-delay corner case in time settings.
  o Fix ipmiseld memleak.
  o Fix libfreeipmi potential fd leak when generating random numbers.
  o Fix libfreeipmi error output bug in RMCP interface.
  o Fix several minor corner cases discovered by static code analysis.
* Thu Nov 15 2012 kkaempf@suse.com
- FreeIPMI 1.2.3 - 11/14/12
  - ------------------------
  Tools
  - -----
  o In ipmi-oem, support new Dell Poweredge R720 OEM commands extensions,
    including:
  - get-nic-selection-failover
  - set-nic-selection-failover
  - power-monitoring-over-interval
  - power-monitoring-interval-range
  - get-last-post-code
  o In ipmi-oem, update active-lom-status for Dell Poweredge R720.
  o In ipmi-oem, support new Dell Poweredge R720 get-system-info option
    'cmc-info'.
  o In ipmi-oem, Dell get-system-info "slot-number" key changed to
    "blade-slot-info".  Legacy option still supported.
  o In ipmi-sel, support Dell Poweredge R720 OEM SEL extensions.
  o In all tools, support nochecksumcheck workaround option.
  o In all daemons (ipmiseld, ipmidetectd, bmc-watchdog), check for
    syscall errors during daemon setup.
  Libraries
  - --------
  o In libfreeipmi, support Dell R720 OEM extension intepretations.
  o In libfreeipmi, libipmimonitoring, and libipmiconsole, support
    NO_CHECKSUM_CHECK workaround flag.
  o In libipmiconsole, IPMICONSOLE_DEBUG_FILE logs debug to files in
    current working directory and not /var/log.  PID is also appended
    to debug files.
  Misc
  - ---
  o Various documentation updates and fixes.
* Thu Oct  4 2012 kkaempf@suse.com
- FreeIPMI 1.2.2 - 10/02/12
  Tools
  - -----
  o Support new --sol-payload-instance and --deactivate-all-instances
    options in ipmiconsole.
  o Fix ipmiseld compile issue with -Werror=format-security.
  Libraries
  - --------
  o In libipmiconsole, add new ipmiconsole_ctx_set_config() and
    ipmiconsole_ctx_get_config() functions.
  o In libipmiconsole, add support for specifying and handling
    different SOL payload instances.  This support includes:
  - Support new IPMICONSOLE_CTX_CONFIG_OPTION_SOL_PAYLOAD_INSTANCE
    configuration option.
  - In libipmiconsole, support new
    IPMICONSOLE_BEHAVIOR_DEACTIVATE_ALL_INSTANCES behavior flag.
  - Return more appropriate error codes when activation limits are
    discovered.
  o In libfreeipmi, fix debug output corner case when outputting byte
    arrays.
  Misc
  - ---
  o Various documentation updates and fixes.
* Mon Jul 30 2012 kkaempf@suse.com
- FreeIPMI 1.1.7 - 07/30/12
  o In ipmi-sensors and ipmi-sel, fix units output corner case.
  o In bmc-info, detect unsupported system info corner case.
  o Update documentation with motherboard support.
  Special Note: This will likely be the last release of FreeIPMI
  in the 1.1.X stable branch.
* Wed Jul  4 2012 kkaempf@suse.com
- Fix build: %%make_install -> %%makeinstall
* Fri Jun 29 2012 kkaempf@suse.com
- FreeIPMI 1.1.6 - 06/28/12
  - Tools
  - -----
  o In ipmi-sel, support Supermicro SEL OEM interpretations in
  - -output-event-state.
  o In ipmi-sel and ipmi-sensors, support additional sensor/SEL
    interpretations including:
  - Version Change
  - System Firmware Progress Transition Severity
  - Button/Switch Transition Severity
  - Chassis Transition Severity
  - POST Memory Resize State
  - Cable/Interconnect Transition Severity
  - Boot Error Transition Severity
  - Slot Connector Transition Severity
  - Memory State
  - Memory Transition Severity
  o In bmc-config, ipmi-chassis-config, ipmi-pef-config, and
    ipmi-chassis-config, support cipher suite ID argument.
  o Support Supermicro X9DRi-F OEM sensors and events.
  o Fix Intel S2600JF/Appro 512x OEM SEL interpretations based on
    comments from Intel.
  Libraries
  - --------
  o Support Supermicro SEL OEM interpretations.
  o Support new sensor/SEL interpretations.
  Misc
  - ---
  o Various documentation updates and fixes.
* Thu May 17 2012 kkaempf@suse.com
- FreeIPMI 1.1.5 - 05/17/12
  Tools
  - -----
  o Support Supermicro OEM sensors/SEL on H8DGU-F motherboards.
  o In ipmiconsole, fix password length check bug.
  o In bmc-watchdog, fix --start-if-stopped and --reset-if-running
    options.
  o In ipmidetectd, fix usage output typos.
  o In ipmi-sensors-config, fix several parallel output corner cases.
  o For consistency to other tools, turn on quiet-caching if
    communicating with multiple hosts in bmc-device and ipmi-oem.
  o In ipmi-sensors, fix bug in which multiple workarounds could not
    be used or used in combination with bridging.
  o Fix start run levels in ipmidetectd init script.
  Libraries
  - --------
  o In libfreeipmi fru-parse API, handle additional device busy errors.
  Misc
  - ---
  o Various documentation updates.
* Tue May  8 2012 trenn@suse.de
- Fix build: Added version 1.1.4 tarball
- Adjust specfile according to spec-cleaner as suggested by Sascha Peilicke
  to get this package into factory.
* Fri Apr 20 2012 kkaempf@suse.com
- FreeIPMI 1.1.4 - 04/19/12
  Tools
  - -----
  o In ipmi-oem, fix error message output in several Supermicro OEM
    commands.
  o In ipmi-oem, add Intel --get-power-restore-delay and
  - -set-power-restore-delay support.
  o In ipmi-sel, support Intel S2600JF/Appro 512x OEM SEL
    interpretations.
  Libraries
  - ---------
  o In libfreeipmi, support new sensor and SEL event
    interpretations, including Session Audit, Voltage Limits.
  o In libfreeipmi, support new OEM interpretations for Intel S5000PAL
    NMI State and SMI timeout sensors/SEL events.
  o In libfreeipmi, support Intel S2600JF/Appro 512x OEM SEL
    interpretations.
  Misc
  - ---
  o Various documentation updates.
* Fri Mar 23 2012 trenn@suse.de
- Adjust source url, downloadable tarballs moved from zresearch
  to ftp.gnu.org
- Update to 1.1.3
* Mon Mar 19 2012 trenn@suse.de
- Adjust .spec file via format_spec_file
* Tue Mar  6 2012 trenn@suse.de
- Update to 1.1.2
- Adjusted license to GPL-3.0
- Silent some build checks:
  - license string
  - too short description
  - remove INSTALL file from %%docdir
* Wed Sep 21 2011 kkaempf@suse.com
- Update to 1.0.6
  o Support 'ignorescanningdisabled' workaround in ipmi-sensors.
  o Support Supermicro X8SIL-F, X9SCL, and X9SCM motherboard OEM sensors.
  o Update bmc-watchdog logrotate script to reduce unnecessary output.
  o Fix ipmi-fru output typo.
- Update to 1.0.5
  o Fix various issues in ipmi-dcmi, including command line parsing
    bugs, asset tag/string identifier overwriting, and fix assumptions
    based on new information in v1.5 errata.
  o Support pkg-config files for libraries.
  o Various documentation updates.
* Sat Apr 23 2011 kkaempf@novell.com
- Update to 1.0.4
  o Support "discretereading" workaround in ipmi-sensors and
    associated libraries.
  o Support "spinpoll" workaround/performance optimization in tools
    and libraries.
  o Support additional sensor/SEL interpretations for Intel
    motherboards.
  o Add convenience input checking functions to libipmiconsole.
  o Fix bug in libipmimonitoring to allow additional OEM
    interpretations.
* Wed Mar 30 2011 kkaempf@novell.com
- update to 1.0.3
  o Support additional error handling in bmc-info.
  o Support ability to set "none" workaround flags on the command
    line and in tools.
  o In libipmiconsole, force ipmiconsole_engine_init() to be
    called before ipmiconsole_ctx_create().
  o Fix libipmiconsole callback semantics.
  o Fix libipmiconsole bugs in overriding standard defaults vs.
    config file defaults.
  o Fix potential race in libipmiconsole during engine teardown.
  o Add package version macros to libfreeipmi.
  o Add library version macros to all libraries.
  o Fix Solaris build bug.
  o Fix config output bug in ipmipower.
- update to 1.0.2
  o Support --ignore-unrecognized-events in ipmi-sensors.
  o Clarify error messages in ipmi-locate.
  o Support Supermicro X7DBR-3, X8DTL-3F, X8DT3-LN4F motherboard OEM
    sensors.
  o Support Dell Module/Board OEM sensor interpretation on Poweredge
    R210 motherboards.
  o In bmc-info, support motherboards that don't implement Get Device
    Guid.
  o In bmc-watchdog, fix error logging corner case.
  o Support new -r option in ganglia_ipmi_sensors.pl plugin to modify
    ipmi hostname.
  o Add workaround for SDR caching compliance bug in HP Proliant
    DL585G7.
  o In bmc-config, add workaround for motherboards that do not allow
    you to configure identical usernames.
  o Various documentation updates.
- update to 1.0.1
  o Remove ipmimonitoring tool. Tool is now superseded by ipmi-sensors
    and the new --output-sensor-state option.
  o Support --output-event-state option for ipmi-sel to support SEL
    event interpretation.
  o All config-tools now support multi-channel configuration under
    verbose mode.
  o Re-architect libipmimonitoring to support all defined IPMI sensor
    types, OEM bitmasks, and OEM interpretations.
  o Add SEL monitoring support to libipmimonitoring.
  o Support new 'interpret' sub-library in libfreeipmi.
  o Support interpretation rules for sensors when no states/events occur.
  o Support interpretation rules for out of spec sensor states/events.
  o Support interpretation rules for OEM sensors and events.
  o Move all config files to /etc/freeipmi/. Support legacy config
    files for backwards compatibility.
  o Support serial keepalive in ipmiconsole to check if serial
    connection has remained alive across system reboots.
  o Create symlinks and manpage pointers for 'ipmi-power', 'ipmi-ping',
    'rmcp-ping', 'ipmi-console', and 'ipmi-detect' to give some additional
    consistency to the tool naming.
  o Various documentation updates.
  o Update to support DCMI 1.1.
  o Update all licensing information to GPLv3.
- update to 0.8.12
  o In bmc-config, workaround RMCP+ Privilege Level configuration
    compliance bugs on HP DL145 servers.
  o In ipmi-chassis-config, after configuring boot flags, set valid bits
    appropriately.
  o Fix N/A output corner case in ipmi-sel.
  o Support Supermicro X8DTU-6+ motherboard OEM sensors.
  o Fix FRU date/time calculation bug that did not account for leap
    years.
- update to 0.8.11
  o Support Fujitsu iRMC S1 and iRMC S2 OEM extensions in
    ipmi-sensors and ipmi-sel.
  o Support --output-oem-event-string in ipmi-sel.
  o Other minor documentation/bug fixes.
- update to 0.8.10
  o Support many new Inventec OEM extensions in ipmi-oem.
  o Support many new Quanta OEM extensions in ipmi-oem.
  o Support many new Intel OEM extensions in ipmi-oem.
  o Support Intel s5500WB OEM extensions in ipmi-sel.
  o Support Intel Node Manager SEL events across Quanta S99Q,
    Inventec 5441, Inventec 5442, and Intel S5500WB motherboards.
  o Move some OEM extensions from Dell section to Inventec section in
    ipmi-oem. Were previously thought to be additions by Dell, but
    in fact are not. Backwards compatability supported.
  o Support 'assumeio' inband workaround globally.
  o Gracefully handle some errors in ipmi-sensors.
  o Fix in-band probing corner case.
  o Fix various parameter input checks in ipmi-oem.
  o Fix help output corner cases in ipmi-oem.
  o Other minor documentation/bug fixes.
- update to 0.8.9
  o In ipmi-sel and ipmimonitoring, workaround Supermicro H8QME SEL
    compliance issues in ipmi-sel.
  o In ipmi-sel, do not report error if SEL is empty.
  o Support Fujitsu 'get-sel-entry-long-text' in ipmi-oem.
  o Fix workaround flags bug in ipmimonitoring.
  o Revert 'Open Session Privilege Workaround' changes in 0.8.8, were
    unnecessary.
  o Fix daylight savings bug when configuring BMC times in bmc-device.
  o Support 'veryslowcommit' workaround for config tools to work around
    very slow BMCs.
  o Support --enable-rawdumps compile option.
  o Support SHA256 in IPMI 2.0.
  o Other minor bug fixes.
- update to 0.8.8
  o Support Supermicro 'get-bmc-services-status' and
    'set-bmc-services-status' in ipmi-oem.
  o Support bmc-watchdog 'ignorestateflag' workaround around more
    issues.
  o Support Open Session Privilege Workaround around more related
    compliance issues.
  o Fix bmc-watchdog --version option.
  o Fix legacy workaround corner case in channel detection for
    Intel nodes.
  o Support Quanta reset-to-defaults command in ipmi-oem.
  o Modify ipmiconsole protocol to not deactivate SOL protocol is
    SOL is already deactivated.
  o Modify ipmiconsole protocol to not error out under several
    malformed packet scenarios.
  o Fix ipmiping/rmcpping command line parsing corner case.
  o Minor documentation updates.
  o Minor error message output fixes.
  o Support --without-random-device configure option for some
    embedded systems.
- update to 0.8.7
  o Support Supermicro X8DTG OEM sensors.
  o Support Supermicro X8DTG workarounds with 'integritycheckvalue'
    workaround flag.
  o Document workarounds for Intel S5500WBV/Penguin Relion 700
    motherboard.
  o Map IPMI 2.0 "invalid role" error code to "privilege level cannot be
    obtained" for better usability.
  o Fix bmc-config Security Keys commit by making some required fields
    optional.
  o Fix bmc-watchdog init script return codes on Suse.
  o Support 'ignorestateflag' workaround in bmc-watchdog.
  o Fix ipmi-sensors corner case for sensors with percentage units.
  o Support 'slowcommit' workaround for config tools to work around
    slower BMCs.
  o Update documentation w/ Supermicro X8DTG issues.
  o Update documentation w/ inband troubleshooting.
- update to 0.8.6
  o Support Quanta S99Q/Dell FS12-TY OEM SEL events.
  o In ipmi-oem, support Quanta S99Q/Dell FS12-TY OEM commands.
  o Fix --key-pair parsing bug in all config tools.
  o Locally support sunbmc driver if bmc_intf.h header not found.
  o If Sunbmc driver is not supported, report "Device Not Supported"
    instead of "Internal Error".
  o Fix error output messages.
  o Fix Solaris install issue.
  o Other minor fixes.
* Fri Apr 30 2010 kkaempf@novell.com
- update to 0.8.5
  - Support Inventec 5442/Dell Xanadu III OEM events.
  - Workaround Quanta S99Q/Dell FS12-TY Node Busy errors.
  - Fix some library error checks limiting bmc-config Bad Password
    Threshold configuration.
  - Fix some library macro names based on actual OEM names.
  - Fix documentation typos.
  (update to 0.8.4)
  - Fix IPMI 2.0 sequence number wrap around corner case.
  - Fix ipmi-sensors --comma-separated-output corner case.
  - In ipmi-sensors, output multiple event strings w/ space
    delimiter in simple output.
  - In ipmi-oem, support Dell get-active-lom-status.
  - In ipmi-oem, support IBM get-led.
  - In ipmi-sel, fix possible --assume-system-event-records
    corner case.
  - Fix Posix portability issue w/ time functions.
  - Minor documentation updates.
* Wed Feb  3 2010 kkaempf@novell.com
- update to 0.8.3
  - fix buffer overflow (was: ipmi-messaging-support-cmds.patch)
* Thu Jan 14 2010 kkaempf@novell.com
- adapt_to_suse_docdir.patch: Use /usr/share/doc/packages/$(name)
- add_default_start.patch: Add 'Default-Start:' to init.d scripts
- ipmi-messaging-support-cmds.patch: Fix buffer overflow
* Thu Jan 14 2010 kkaempf@novell.com
- Update to 0.8.2
